==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXUsb.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXUsb::BEGIN{package NXUsb;no warnings;require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}package NXUsb;no warnings;
%usbDB;sub list{(my $extended=(shift (@_)||(0x00e5+ 8192-0x20e5)));(my $username
=(shift (@_)||("")));(my (%usbList)=());(my $result=getUsbList ((\%usbList),
$username));if (($result!=(0x0d13+ 2002-0x14e5))){printUsbList ((\%usbList),
$extended);}else{Common::NXMsg::error (
"\x65\x43\x4d\x44\x55\x73\x62\x4c\x69\x73\x74\x46\x61\x69\x6c\x65\x64");}}sub 
add{(my $encodedLine=shift (@_));(my $line=main::urldecode ($encodedLine));(my $usb
=__parseUsbCommandLine ($line));(my $sessionId=Server::getMySessionID ());(my $record
=__createRecord ($sessionId,NXLogin::getCurrentUser (),$usb));(my $result=__add 
($record));(my $hubPort=$$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"});if (($result
==(0x0029+ 5809-0x16da))){Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x41\x64\x64\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}}sub __createRecord{(my $sessionId=shift (@_));(my $username
=shift (@_));(my $ref_usb=shift (@_));(my $record=(""));($record.=($username.
"\x3a"));($record.=($sessionId."\x3a"));($record.=($$ref_usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}."\x3a"));($record.=($$ref_usb{
"\x48\x75\x62\x2d\x50\x6f\x72\x74"}."\x3a"));($record.=($$ref_usb{
"\x53\x74\x61\x74\x75\x73"}."\x3a"));($record.=($$ref_usb{"\x4e\x6f\x64\x65\x73"
}."\x3a"));($record.="\x0a");return ($record);}sub delete{(my $encodedLine=shift
 (@_));(my $line=main::urldecode ($encodedLine));(my $usb=__parseUsbCommandLine 
($line));(my $sessionId=Server::getMySessionID ());(my $hubPort=$$usb{
"\x48\x75\x62\x2d\x50\x6f\x72\x74"});(my $result=__del ($sessionId,$hubPort));if
 (($result==(0x06d4+ 7579-0x246f))){Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x44\x65\x6c\x65\x74\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}}sub deleteBySessionId{(my $sessionId=shift (@_));(my $result
=__del ($sessionId));if (($result==(0x1c6a+ 823-0x1fa1))){Logger::warning (((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x55\x73\x62\x3a\x20\x44\x65\x6c\x65\x74\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x2e"));}}sub deleteMySession{return (deleteBySessionId (
Server::getMySessionID ()));}sub __parseUsbCommandLine{(my $lineToParse=shift (
@_));($lineToParse=~ s/[\r\n]//g );(my (@line)=split ( /,/ ,$lineToParse,
(0x00e7+ 5201-0x1538)));(my (%usb)=());($usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}=$line[(0x126f+ 2895-0x1dbe)]);(
$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"}=$line[(0x02c0+ 3898-0x11f9)]);($usb{
"\x53\x74\x61\x74\x75\x73"}=$line[(0x0b1f+ 237-0x0c0a)]);($usb{
"\x4e\x6f\x64\x65\x73"}=$line[(0x0f62+ 1193-0x1408)]);return ((\%usb));}sub 
getUsbList{(my $ref_usbList=shift (@_));(my $username=shift (@_));(my $dbFilePath
=NXPaths::getUsbDBPath ());(my $handle=main::nxopen ($dbFilePath,
$NXBits::O_RDONLY));if (defined ($handle)){my ($line);while (main::nxreadLine (
$handle,(\$line))){(my $usb=__parseDBLine ($line));if ($username){if (($username
 eq $$usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"})){($$ref_usbList{$i++}=$usb);}}
else{($$ref_usbList{$i++}=$usb);}}main::nxclose ($handle);}else{return (
(0x17d1+ 1135-0x1c40));}return ((0x0842+ 6197-0x2076));}sub printUsbList{(my $ref_usbList
=shift (@_));(my $extended=(shift (@_)||(0x0a49+ 3047-0x1630)));(my (@labels)=(
"\x55\x73\x65\x72\x6e\x61\x6d\x65","\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44",
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65",
"\x48\x75\x62\x2d\x50\x6f\x72\x74","\x53\x74\x61\x74\x75\x73"));if ($extended){
push (@labels,"\x4e\x6f\x64\x65\x73");}Common::NXMsg::info (
"\x69\x43\x4d\x44\x55\x73\x62\x4c\x69\x73\x74");return (NXTools::printTable ((
\@labels),$ref_usbList));}sub __add{(my $record=shift (@_));(my $dbFilePath=
NXPaths::getUsbDBPath ());(my $lockHandle=main::lockFileDirect ($dbFilePath,
$NXBits::LOCK_EX));(my $dbHandle=main::nxopen ($dbFilePath,(($NXBits::O_WRONLY+
$NXBits::O_CREAT)+$NXBits::O_APPEND),$NXBits::UserReadWrite));if ((not (defined 
($dbHandle)))){main::unLockFileDirect ($lockHandle);(my $errorString=
libnxh::NXGetErrorString ());Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x66\x69\x6c\x65\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x1475+ 226-0x1557));}(my $bytes=main::nxwrite ($dbHandle,
$record));if (($bytes==(-(0x08d2+ 5888-0x1fd1)))){(my $errorString=
libnxh::NXGetErrorString ());main::nxclose ($dbHandle);main::unLockFileDirect (
$lockHandle);Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x034a+ 3524-0x110e));}main::nxclose ($dbHandle);
main::unLockFileDirect ($lockHandle);return ((0x032c+ 8440-0x2423));}sub __del{(my $sessionId
=shift (@_));(my $hubPort=shift (@_));(my $dbFilePath=NXPaths::getUsbDBPath ());
(my $flag_del=(0x20f7+ 672-0x2397));(my $lockHandle=main::lockFileDirect (
$dbFilePath,$NXBits::LOCK_EX));(my $dbHandle=main::nxopen ($dbFilePath,
$NXBits::O_RDONLY,(0x090c+ 6223-0x215b)));if ((not (defined ($dbHandle)))){(my $errorString
=libnxh::NXGetErrorString ());main::unLockFileDirect ($lockHandle);
Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x0270+ 5698-0x18b2));}(my $tempdbFilePath=(($dbFilePath.
"\x2e\x74\x6d\x70\x2e").$ $));
 if (Common::NXFile::isExists ($tempdbFilePath)){
unlink ($tempdbFilePath);}(my $tmpHandle=main::nxopen ($tempdbFilePath,((
$NXBits::O_CREAT+$NXBits::O_WRONLY)+$NXBits::O_APPEND),$NXBits::UserReadWrite));
if ((not (defined ($tmpHandle)))){(my $errorString=libnxh::NXGetErrorString ());
main::nxclose ($dbHandle);main::unLockFileDirect ($lockHandle);Logger::warning (
((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x3a\x20"
.$tempdbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").
$errorString)."\x27"));return ((0x02e4+ 1447-0x088b));}&try (sub{my ($line);
while (main::nxreadLine ($dbHandle,(\$line))){(my $usb=__parseDBLine ($line));(
$usbDB{$$usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"}}=$usb);if ((($sessionId ne 
$$usb{"\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44"})or ($hubPort and ($hubPort ne 
$$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"})))){
Common::NXCore::nxwriteOrThrowException ($tmpHandle,$line);}}},&otherwise (sub{(my $error
=shift (@_));main::nxclose ($tmpHandle);main::nxclose ($dbHandle);
main::unLockFileDirect ($lockHandle);Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x3a\x20"
.$tempdbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$error).
"\x27"));return ((0x02ac+ 6331-0x1b67));}));main::nxclose ($tmpHandle);
main::nxclose ($dbHandle);if ((not (Common::NXFile::renameFile ($tempdbFilePath,
$dbFilePath)))){(my $errorString=libnxh::NXGetErrorString ());
main::unLockFileDirect ($lockHandle);Logger::warning (((((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x3a\x3a\x20"
.$tempdbFilePath)."\x20\x74\x6f\x3a\x20").$dbFilePath).
"\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString)."\x27"));
return ((0x0252+ 508-0x044e));}main::unLockFileDirect ($lockHandle);return (
(0x1c47+ 823-0x1f7d));}sub __parseDBLine{(my $lineToParse=shift (@_));(
$lineToParse=~ s/[\r\n]//g );(my (@line)=split ( /:/ ,$lineToParse,
(0x079a+ 5779-0x1e2d)));(my (%usb)=());($usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"}
=$line[(0x14eb+ 4306-0x25bd)]);($usb{"\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44"}
=$line[(0x016b+ 2332-0x0a86)]);($usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}=$line[(0x162a+ 3273-0x22f1)]);(
$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"}=$line[(0x19f1+ 194-0x1ab0)]);($usb{
"\x53\x74\x61\x74\x75\x73"}=$line[(0x0c93+ 3451-0x1a0a)]);($usb{
"\x4e\x6f\x64\x65\x73"}=$line[(0x0957+ 6027-0x20dd)]);return ((\%usb));}
"\x3f\x3f\x3f";

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXUsb.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXUsb::BEGIN{package NXUsb;no warnings;require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}package NXUsb;no warnings;
%usbDB;sub list{(my $extended=(shift (@_)||(0x11d1+ 4053-0x21a6)));(my $username
=(shift (@_)||("")));(my (%usbList)=());(my $result=getUsbList ((\%usbList),
$username));if (($result!=(0x0741+ 2174-0x0fbf))){printUsbList ((\%usbList),
$extended);}else{Common::NXMsg::error (
"\x65\x43\x4d\x44\x55\x73\x62\x4c\x69\x73\x74\x46\x61\x69\x6c\x65\x64");}}sub 
add{(my $encodedLine=shift (@_));(my $line=main::urldecode ($encodedLine));(my $usb
=__parseUsbCommandLine ($line));(my $sessionId=Server::getMySessionID ());(my $record
=__createRecord ($sessionId,NXLogin::getCurrentUser (),$usb));(my $result=__add 
($record));(my $hubPort=$$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"});if (($result
==(0x0360+ 1973-0x0b15))){Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x41\x64\x64\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}}sub __createRecord{(my $sessionId=shift (@_));(my $username
=shift (@_));(my $ref_usb=shift (@_));(my $record=(""));($record.=($username.
"\x3a"));($record.=($sessionId."\x3a"));($record.=($$ref_usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}."\x3a"));($record.=($$ref_usb{
"\x48\x75\x62\x2d\x50\x6f\x72\x74"}."\x3a"));($record.=($$ref_usb{
"\x53\x74\x61\x74\x75\x73"}."\x3a"));($record.=($$ref_usb{"\x4e\x6f\x64\x65\x73"
}."\x3a"));($record.="\x0a");return ($record);}sub delete{(my $encodedLine=shift
 (@_));(my $line=main::urldecode ($encodedLine));(my $usb=__parseUsbCommandLine 
($line));(my $sessionId=Server::getMySessionID ());(my $hubPort=$$usb{
"\x48\x75\x62\x2d\x50\x6f\x72\x74"});(my $result=__del ($sessionId,$hubPort));if
 (($result==(0x15ab+ 3625-0x23d4))){Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x44\x65\x6c\x65\x74\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x20\x77\x69\x74\x68\x20\x48\x75\x62\x2d\x50\x6f\x72\x74\x3a\x20")
.$hubPort)."\x2e"));}}sub deleteBySessionId{(my $sessionId=shift (@_));(my $result
=__del ($sessionId));if (($result==(0x10cd+ 2645-0x1b22))){Logger::warning (((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x55\x73\x62\x3a\x20\x44\x65\x6c\x65\x74\x65\x64\x20\x75\x73\x62\x20\x65\x6e\x74\x72\x79\x20\x66\x6f\x72\x3a\x20"
.$sessionId)."\x2e"));}}sub deleteMySession{return (deleteBySessionId (
Server::getMySessionID ()));}sub __parseUsbCommandLine{(my $lineToParse=shift (
@_));($lineToParse=~ s/[\r\n]//g );(my (@line)=split ( /,/ ,$lineToParse,
(0x05d9+ 4253-0x1676)));(my (%usb)=());($usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}=$line[(0x1160+ 3557-0x1f45)]);(
$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"}=$line[(0x236d+ 366-0x24da)]);($usb{
"\x53\x74\x61\x74\x75\x73"}=$line[(0x222a+ 735-0x2507)]);($usb{
"\x4e\x6f\x64\x65\x73"}=$line[(0x0e65+ 4960-0x21c2)]);return ((\%usb));}sub 
getUsbList{(my $ref_usbList=shift (@_));(my $username=shift (@_));(my $dbFilePath
=NXPaths::getUsbDBPath ());(my $handle=main::nxopen ($dbFilePath,
$NXBits::O_RDONLY));if (defined ($handle)){my ($line);while (main::nxreadLine (
$handle,(\$line))){(my $usb=__parseDBLine ($line));if ($username){if (($username
 eq $$usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"})){($$ref_usbList{$i++}=$usb);}}
else{($$ref_usbList{$i++}=$usb);}}main::nxclose ($handle);}else{return (
(0x0c0d+ 852-0x0f61));}return ((0x044f+ 1317-0x0973));}sub printUsbList{(my $ref_usbList
=shift (@_));(my $extended=(shift (@_)||(0x0399+ 3470-0x1127)));(my (@labels)=(
"\x55\x73\x65\x72\x6e\x61\x6d\x65","\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44",
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65",
"\x48\x75\x62\x2d\x50\x6f\x72\x74","\x53\x74\x61\x74\x75\x73"));if ($extended){
push (@labels,"\x4e\x6f\x64\x65\x73");}Common::NXMsg::info (
"\x69\x43\x4d\x44\x55\x73\x62\x4c\x69\x73\x74");return (NXTools::printTable ((
\@labels),$ref_usbList));}sub __add{(my $record=shift (@_));(my $dbFilePath=
NXPaths::getUsbDBPath ());(my $lockHandle=main::lockFileDirect ($dbFilePath,
$NXBits::LOCK_EX));(my $dbHandle=main::nxopen ($dbFilePath,(($NXBits::O_WRONLY+
$NXBits::O_CREAT)+$NXBits::O_APPEND),$NXBits::UserReadWrite));if ((not (defined 
($dbHandle)))){main::unLockFileDirect ($lockHandle);(my $errorString=
libnxh::NXGetErrorString ());Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x20\x66\x69\x6c\x65\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x047b+ 5869-0x1b68));}(my $bytes=main::nxwrite ($dbHandle,
$record));if (($bytes==(-(0x05af+ 1169-0x0a3f)))){(my $errorString=
libnxh::NXGetErrorString ());main::nxclose ($dbHandle);main::unLockFileDirect (
$lockHandle);Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x0b55+ 2507-0x1520));}main::nxclose ($dbHandle);
main::unLockFileDirect ($lockHandle);return ((0x129d+ 1345-0x17dd));}sub __del{(my $sessionId
=shift (@_));(my $hubPort=shift (@_));(my $dbFilePath=NXPaths::getUsbDBPath ());
(my $flag_del=(0x0672+ 4044-0x163e));(my $lockHandle=main::lockFileDirect (
$dbFilePath,$NXBits::LOCK_EX));(my $dbHandle=main::nxopen ($dbFilePath,
$NXBits::O_RDONLY,(0x05c4+ 7524-0x2328)));if ((not (defined ($dbHandle)))){(my $errorString
=libnxh::NXGetErrorString ());main::unLockFileDirect ($lockHandle);
Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x3a\x20"
.$dbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString).
"\x27"));return ((0x028a+ 7800-0x2102));}(my $tempdbFilePath=(($dbFilePath.
"\x2e\x74\x6d\x70\x2e").$ $));
 if (Common::NXFile::isExists ($tempdbFilePath)){
unlink ($tempdbFilePath);}(my $tmpHandle=main::nxopen ($tempdbFilePath,((
$NXBits::O_CREAT+$NXBits::O_WRONLY)+$NXBits::O_APPEND),$NXBits::UserReadWrite));
if ((not (defined ($tmpHandle)))){(my $errorString=libnxh::NXGetErrorString ());
main::nxclose ($dbHandle);main::unLockFileDirect ($lockHandle);Logger::warning (
((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x6f\x70\x65\x6e\x3a\x20"
.$tempdbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").
$errorString)."\x27"));return ((0x13b5+ 1877-0x1b0a));}&try (sub{my ($line);
while (main::nxreadLine ($dbHandle,(\$line))){(my $usb=__parseDBLine ($line));(
$usbDB{$$usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"}}=$usb);if ((($sessionId ne 
$$usb{"\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44"})or ($hubPort and ($hubPort ne 
$$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"})))){
Common::NXCore::nxwriteOrThrowException ($tmpHandle,$line);}}},&otherwise (sub{(my $error
=shift (@_));main::nxclose ($tmpHandle);main::nxclose ($dbHandle);
main::unLockFileDirect ($lockHandle);Logger::warning (((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x77\x72\x69\x74\x65\x20\x74\x6f\x3a\x20"
.$tempdbFilePath)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$error).
"\x27"));return ((0x1436+ 2976-0x1fd6));}));main::nxclose ($tmpHandle);
main::nxclose ($dbHandle);if ((not (Common::NXFile::renameFile ($tempdbFilePath,
$dbFilePath)))){(my $errorString=libnxh::NXGetErrorString ());
main::unLockFileDirect ($lockHandle);Logger::warning (((((((
"\x4e\x58\x55\x73\x62\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x3a\x3a\x20"
.$tempdbFilePath)."\x20\x74\x6f\x3a\x20").$dbFilePath).
"\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x27").$errorString)."\x27"));
return ((0x0650+ 991-0x0a2f));}main::unLockFileDirect ($lockHandle);return (
(0x0d7a+ 6386-0x266b));}sub __parseDBLine{(my $lineToParse=shift (@_));(
$lineToParse=~ s/[\r\n]//g );(my (@line)=split ( /:/ ,$lineToParse,
(0x03ea+ 437-0x059f)));(my (%usb)=());($usb{"\x55\x73\x65\x72\x6e\x61\x6d\x65"}=
$line[(0x0390+ 3621-0x11b5)]);($usb{"\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44"}=
$line[(0x05bd+ 6662-0x1fc2)]);($usb{
"\x44\x65\x76\x69\x63\x65\x20\x6e\x61\x6d\x65"}=$line[(0x001a+  70-0x005e)]);(
$usb{"\x48\x75\x62\x2d\x50\x6f\x72\x74"}=$line[(0x08cb+ 2439-0x124f)]);($usb{
"\x53\x74\x61\x74\x75\x73"}=$line[(0x0cd5+ 3369-0x19fa)]);($usb{
"\x4e\x6f\x64\x65\x73"}=$line[(0x0e2b+ 1424-0x13b6)]);return ((\%usb));}
"\x3f\x3f\x3f";
